=============
Signals Utils
=============

Mongo signals utils for the curator core project.

Quick start
===========

1. Add "signals_utils" to your INSTALLED_APPS setting
-----------------------------------------------------

.. code:: python

    INSTALLED_APPS = [
      ...
      'signals_utils',
    ]
